@@ -266,11 +266,20 @@ foreach my $Marker ($xc->findnodes("/fb3:fb3-body/fb3:section//fb3:marker")) {
 }
 
 if ($OPT{'skip_halfempty_section'}) {
+  # remove clipped
   foreach my $Sec ($xc->findnodes("/fb3:fb3-body/fb3:section")) {
-    my @N = $Sec->findnodes("./*");
-    if (
-      ( grep {lc($_->nodeName()) eq 'title'} @N) && !(grep {lc($_->nodeName()) eq 'p'} @N)
-    ) {
+    my $Remove=0;
+    if ($Sec->getAttribute('clipped') && $Sec->getAttribute('clipped') eq 'true') {
+      $Remove = 1;
+    } else {
+      my @N = $Sec->findnodes("./*");
+      if (
+        ( grep {lc($_->nodeName()) eq 'title'} @N) && !(grep {lc($_->nodeName()) eq 'p'} @N)
+      ) {
+        $Remove = 1;
+      }
+    }
+    if ($Remove) {
       $Sec->parentNode->removeChild($Sec);
       $ChangedByNode=1;
     }
@@ -292,11 +301,26 @@ foreach my $NodeWithId ($xc->findnodes("/fb3:fb3-body/fb3:section//fb3:p//fb3:*"
         $Parent->setAttribute('id' => $NodeID);
         $ChangedByNode = 1;
       }
+
+      if (lc($Parent->parentNode()->nodeName()) eq 'td') {
+        my $ParentTD = $Parent->parentNode();
+        my $ParentIDTD = $ParentTD->getAttribute('id');
+        if ($ParentIDTD) {
+          #уже есть id, придется менять линки в документе на него
+          $LinkRels{$NodeID} = $ParentIDTD; 
+        } else {
+          $ParentIDTD = $NodeID;
+          $ParentTD->setAttribute('id' => $ParentIDTD);
+          $ChangedByNode = 1;
+        }
+      }
+
       last;
     }
   }
 }
 ## /change node id
+
 if ($ChangedByTitle || $ChangedByNode) {
   my $RootNode = $xc->findnodes("/fb3:fb3-body")->[0];
   $BodyXML = $RootNode->toString();
@@ -455,8 +479,6 @@ sub RootNode {
  
 }
 
-
-
 #следим чтобы имя не повторилось
 sub SvgUnique {
   my $Name = shift;
